import { ProColumns } from '@ant-design/pro-components';
import { Button, Popconfirm, Space, Switch, Tooltip } from 'antd';

export const columns = (
  edit: (b: boolean, v: any) => void,
  del: (id: any) => void,
  stateUpdata: (id: any, ck: boolean) => void,
  enumList?: { [key: string]: any },
): ProColumns<any>[] => {
  return [
    {
      title: 'ID',
      dataIndex: 'id',
      key: 'id',
      align: 'center',
      width: 70,
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '组件名称',
      dataIndex: 'componentName',
      align: 'center',
      width: 70,
      ellipsis: true,
    },
    {
      title: '备注',
      dataIndex: 'remark',
      align: 'center',
      width: 70,
      ellipsis: true,
      hideInSearch: true
    },
    {
      title: '组件使用平台',
      dataIndex: 'enabledAppTypes',
      valueType:'select',
      align: 'center',
      width: 80,
      ellipsis: true,
      valueEnum: () => {
        let arr = enumList?.APP_TYPE?.values;
        return arr
          ? new Map([...arr]?.map(({ value, description }: any) => [value, description]))
          : {};
      }
    },
    {
      title: '状态',
      dataIndex: 'enabled',
      key: 'enabled',
      width: 80,
      align: 'center',
      ellipsis: true,
      hideInSearch: true,
      render: (a: any, b: any) => {
        return (
          <Switch
            checkedChildren="正常"
            unCheckedChildren="停用"
            checked={b?.enabled}
            onChange={(ck) => {
              stateUpdata(b.id, ck);
            }}
          />
        );
      },
    },
    {
      title: '操作',
      dataIndex: 'cz',
      key: 'cz',
      width: 160,
      align: 'center',
      hideInSearch: true,
      render: (a: any, b: any) => {
        return (
          <Space size={[0, 0]}>
            <Button
              onClick={() => {
                edit(true, b);
              }}
              size="small"
              type="link"
            >
              编辑
            </Button>
            <Popconfirm
              title={
                <div>
                  确定要删除<span style={{ color: 'red' }}>{b.componentName}</span>组件?
                </div>
              }
              onConfirm={() => {
                del(b.id);
              }}
            >
              <Button size="small" danger type="link">
                删除
              </Button>
            </Popconfirm>
          </Space>
        );
      },
    },
  ];
};
