import { useAjax } from '@/Hook/useAjax';
import { apiDistributorInfoList } from '@/services/distribution/info';
import {
  apiWxAppInfo,
  apiWxAppInfoPageList,
  apiWxAppInfoRemove,
  apiWxAppInfoUpdate,
  apiWxAppInfoUpdateEnabled,
  apiWxAppInfoWxAppConfigAddOrEdit,
  wechatMchAll,
} from '@/services/distribution/weChatInfo';
import { PlusCircleOutlined } from '@ant-design/icons';
import {
  ActionType,
  BetaSchemaForm,
  PageContainer,
  ProFormInstance,
} from '@ant-design/pro-components';
import { useModel } from '@umijs/max';
import { Button, Drawer, message } from 'antd';
import { useCallback, useEffect, useRef, useState } from 'react';
import formConfig from './formConfig';
import { columns } from './tableConfig';
import { appPageList } from '@/services/distribution/pagesManage';
import LongBook from '@/pages/distribution/book/longBook'
import ShortBook from '@/pages/distribution/book/shortBook'
import MyProTable from '@/components/MyProTable';
type DataItem = {
  name: string;
  state: string;
};
const Page: React.FC = () => {
  const formRef = useRef<ProFormInstance>();
  const assignRormRef = useRef<ProFormInstance>();
  const actionRef = useRef<ActionType>();
  let { state, getEnum } = useModel('global');
  let [open, setOpen] = useState<any>(null); //新增
  let [assignOpen, setAssignOpen] = useState(false);
  let [editValues, setEditValues] = useState<any>({});
  let [bookManage, setBookManage] = useState<any>(null);
  let WxAppInfoUpdateEnabled = useAjax((params) => apiWxAppInfoUpdateEnabled(params)); //微信小程序状态更新
  let WxAppInfoUpdate = useAjax((params) => apiWxAppInfoUpdate(params)); //微信小程序信息更新
  let WxAppInfo = useAjax((params) => apiWxAppInfo(params)); //微信小程序信息新增
  let WxAppInfoPageList = useAjax((params) => apiWxAppInfoPageList(params), { type: 'table' }); //微信小程序分页列表
  let WxAppInfoRemove = useAjax((distributorId) => apiWxAppInfoRemove(distributorId)); //小程序删除
  let getWechatMchAll = useAjax(() => wechatMchAll()); //商户列表
  let appPageListApi = useAjax((params) => appPageList(params), { type: 'noPage' });//页面模板列表
  let WxAppInfoWxAppConfigAddOrEdit = useAjax((distributorId) =>
    apiWxAppInfoWxAppConfigAddOrEdit(distributorId),
  ); //指派
  let DistributorInfoList = useAjax((params) => apiDistributorInfoList(params)); //分销商列表
  useEffect(() => {
    appPageListApi.run()
    getWechatMchAll.run();
    DistributorInfoList.run();
  }, []);
  // 删除
  const del = (id: any) => {
    WxAppInfoRemove.run(id).then((res) => {
      if (res.code === 200) {
        actionRef?.current?.reload();
        message.success('删除成功');
      }
    });
  };
  // 状态更新
  const stateUpdata = (id: any, ck: boolean) => {
    WxAppInfoUpdateEnabled.run({ id, enabled: ck }).then((res) => {
      if (res.data) {
        actionRef?.current?.reload();
        message.success(ck ? '启动成功' : '停用成功');
      }
    });
  };
  // 指派
  const mimiAssign = useCallback(
    (params?: any) => {
      setEditValues(params);
      setAssignOpen(true);
      setTimeout(() => {
        assignRormRef?.current?.setFieldsValue({ distributorIds: params?.distributorIds, advertisingChannels: params?.advertisingChannels });
      }, 50)
    },
    [WxAppInfoPageList],
  );
  const assign = async (values: any) => {
    values.appId = editValues.id;
    WxAppInfoWxAppConfigAddOrEdit.run(values).then((res) => {
      if (res.code === 200) {
        actionRef?.current?.reload();
        message.success('操作成功!');
        setEditValues({});
        setAssignOpen(false);
      }
    });
  };
  // 新增 or 编辑
  const submit = async (values: any) => {
    let api = editValues?.id ? WxAppInfoUpdate : WxAppInfo;
    if (editValues?.id) {
      values.id = editValues?.id;
    }
    api.run(values).then((res) => {
      if (res.code === 200) {
        actionRef?.current?.reload();
        message.success('操作成功!');
        closeForm(false);
      }
    });
    console.log(values);
  };
  // 关闭表单弹窗和重置表单内容
  const closeForm = (b: boolean, values?: any) => {
    if (!b) {
      setEditValues({});
      formRef?.current?.resetFields?.();
      setOpen(b);
    } else {
      setEditValues(values);
      setTimeout(() => {
        formRef?.current?.setFieldsValue({ ...values, mchId: values?.mchInfo?.id });
      }, 100);
      setOpen(b);
    }
  };
  return (
    <PageContainer>
      <MyProTable<any, any>
        headerTitle={'小程序列表'}
        actionRef={actionRef}
        rowKey={(r) => r.id}
        search={{
          labelWidth: 120,
          span: 5
        }}
        scroll={{ x: 'max-content' }}
        request={async (params) => {
          return await WxAppInfoPageList.run(params);
        }}
        toolBarRender={() => {
          return [
            <Button
              type="primary"
              onClick={() => {
                setOpen(true);
              }}
            >
              <PlusCircleOutlined />
              新增小程序
            </Button>,
          ];
        }}
        columns={columns(closeForm, del, stateUpdata, mimiAssign, setBookManage)}
      // bordered
      />
      {/* 新增修改 */}
      <BetaSchemaForm<DataItem>
        title={!editValues?.id ? '新增小程序' : '编辑小程序'}
        formRef={formRef}
        width={600}
        open={open}
        onOpenChange={(b) => {
          !b && closeForm(b);
        }}
        layoutType={'ModalForm'}
        labelCol={{ span: 6 }}
        wrapperCol={{ span: 14 }}
        grid={true}
        rowProps={{ gutter: [10, 10] }}
        layout="horizontal"
        onFinish={submit}
        columns={formConfig(state?.enumList, getWechatMchAll?.data?.data, appPageListApi?.data?.data, DistributorInfoList?.data?.data)}
        loading={WxAppInfoUpdate?.loading || WxAppInfo?.loading}
      />
      {/*指派  */}
      <BetaSchemaForm<DataItem>
        title={editValues?.appName + '小程序指派'}
        formRef={assignRormRef}
        width={700}
        open={assignOpen}
        onOpenChange={(b) => {
          if (!b) {
            setEditValues({});
            setAssignOpen(false);
          }
        }}
        layoutType={'ModalForm'}
        labelCol={{ span: 6 }}
        wrapperCol={{ span: 14 }}
        grid={true}
        layout="horizontal"
        onFinish={assign}
        modalProps={{
          destroyOnClose: true
        }}
        columns={[
          {
            title: '分销商',
            dataIndex: 'distributorIds',
            fieldProps:{
              mode: "multiple",
            },
            formItemProps: {
              style: { marginBottom: 10 },
              rules: [
                {
                  required: true,
                  message: '此项为必填项',
                },
              ],
            },
            valueEnum: () => {
              let arr = DistributorInfoList?.data?.data;
              return new Map(arr?.map(({ id, companyName }: any) => [id, companyName]));
            },
          },
          {
            title: '允许投放的载体',
            dataIndex: 'advertisingChannels',
            formItemProps: {
              style: { marginBottom: 10 },
              rules: [
                {
                  required: true,
                  message: '此项为必填项',
                },
              ],
            },
            valueType: 'checkbox',
            valueEnum: getEnum("ADVERTISING_CHANNEL", 'map'),
          },
        ]}
        loading={WxAppInfoWxAppConfigAddOrEdit?.loading}
      />
      {/* 小说管理 */}
      <Drawer
        title={`《${bookManage?.appName}》` + "小说批量移除管理"}
        open={!!bookManage}
        destroyOnClose
        onClose={() => { setBookManage(null) }}
        footer={null}
        width={'90vw'}
      >
        {bookManage?.appCategory === 1 ? <LongBook wechatAppId={bookManage?.id} /> : <ShortBook wechatAppId={bookManage?.id} />}
      </Drawer>
    </PageContainer>
  );
};
export default Page;
