import { ProColumns } from '@ant-design/pro-components';
import { Tag, Button, Popconfirm, Space, Switch, Tooltip } from 'antd';
import Users from './user'
import { useModel } from '@umijs/max';
export const columns = (
  edit: (b: boolean, v: any) => void,
  del: (id: any) => void,
  stateUpdata: (id: any, ck: boolean) => void,
  mimiAssign: (b: any) => void,
  setBookManage: (b: any) => void
): ProColumns<any>[] => {
  let { getEnum } = useModel('global');
  return [
    {
      title: 'ID',
      dataIndex: 'id',
      key: 'id',
      align: 'center',
      width: 70,
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '小程序appId',
      dataIndex: 'wechatAppId',
      key: 'wechatAppId',
      align: 'center',
      width: 70,
      ellipsis: true,
    },
    {
      title: '小程序名称',
      dataIndex: 'appName',
      key: 'appName',
      width: 80,
      ellipsis: true,
      align: 'center',
    },
    {
      title: '小程序类别',
      dataIndex: 'appCategory',
      key: 'appCategory',
      width: 80,
      ellipsis: true,
      align: 'center',
      valueEnum: () => {
        let arr = [{ value: 1, text: "长篇" }, { value: 2, text: "短篇" }]
        return new Map(arr.map(item => [item.value, item.text]))
      },
    },
    {
      title: '小程序页面模板',
      dataIndex: 'templateName',
      key: 'templateName',
      width: 80,
      ellipsis: true,
      align: 'center',
    },
    {
      title: '小程序首页链接',
      dataIndex: 'homePage',
      key: 'homePage',
      width: 80,
      ellipsis: true,
      align: 'center',
      hideInSearch: true,
    },
    {
      title: '小程序版本号',
      dataIndex: 'appVersion',
      key: 'appVersion',
      width: 80,
      ellipsis: true,
      align: 'center',
      hideInSearch: true,
    },
    {
      title: 'ios支付版本号',
      width: 80,
      ellipsis: true,
      align: 'center',
      tooltip: "ios的特殊性,此版本号与IOS支付模块关联,小程序版本号<=此版本号IOS才会出现支付功能,(微信)小程序发布线上后必须设置",
      dataIndex: 'iosPayment',
      hideInSearch: true,
      render: (_, d) => {
        return d.iosPayment ? <Tag color={d.iosPayment === d.appVersion ? "processing" : "error"} bordered={false}> {d.iosPayment} </Tag> : <Tag color="error" bordered={false}>IOS无法支付</Tag>
      }
    },
    {
      title: '备注',
      dataIndex: 'remark',
      key: 'remark',
      width: 80,
      align: 'center',
      ellipsis: true,
      hideInSearch: true,
    },

    {
      title: '状态',
      dataIndex: 'enabled',
      key: 'enabled',
      width: 80,
      align: 'center',
      ellipsis: true,
      hideInSearch: true,
      render: (a: any, b: any) => {
        return (
          <Switch
            checkedChildren="正常"
            unCheckedChildren="停用"
            checked={b?.enabled}
            onChange={(ck) => {
              stateUpdata(b.id, ck);
            }}
          />
        );
      },
    },
    {
      title: '已指派(分销商)',
      dataIndex: 'distributorInfos',
      width: 80,
      align: 'center',
      ellipsis: true,
      hideInSearch: true,
      render: (a, b: any) => {
        return b?.distributorInfos?.map((item: any) => <Tag color={"geekblue"} bordered={false} key={item.id}> {item?.companyName} </Tag>);
      },
    },
    {
      title: '允许投放载体',
      dataIndex: 'advertisingChannels',
      width: 80,
      align: 'center',
      ellipsis: true,
      hideInSearch: true,
      render: (a, b: any) => {
        let map = getEnum("ADVERTISING_CHANNEL", 'map')
        return b?.advertisingChannels?.map((n: any) => <Tag color={"processing"} bordered={false} key={n}> {map.get(n)} </Tag>)
      },
    },
    {
      title: '商户',
      dataIndex: 'mchName',
      width: 80,
      align: 'center',
      ellipsis: true,
      hideInSearch: true,
      render: (a, b: any) => {
        return <a>{b?.mchInfo?.mchName}</a>;
      },
    },
    {
      title: '操作',
      dataIndex: 'cz',
      key: 'cz',
      width: 160,
      align: 'center',
      hideInSearch: true,
      render: (a: any, b: any) => {
        return (
          <Space size={[0, 0]}>
            <Button
              onClick={() => {
                edit(true, b);
              }}
              size="small"
              type="link"
            >
              编辑
            </Button>
            <Popconfirm
              title={
                <div>
                  确定要删除<span style={{ color: 'red' }}>{b.appName}</span>小程序?
                </div>
              }
              onConfirm={() => {
                del(b.id);
              }}
            >
              <Button size="small" danger type="link">
                删除
              </Button>
            </Popconfirm>
            <Button
              onClick={() => {
                mimiAssign(b);
              }}
              size="small"
              type="link"
            >
              指派
            </Button>
            <Users data={b} />
            <Button
              onClick={() => {
                setBookManage(b);
              }}
              size="small"
              type="link"
            >
              小说管理
            </Button>
          </Space>
        );
      },
    },
  ];
};
