import { ProColumns } from '@ant-design/pro-components';
import { useModel } from '@umijs/max';
import { Space } from 'antd';

export const columns = (): ProColumns<any>[] => {
  let { getEnum } = useModel('global')
  return [
    {
      title: 'openId',
      dataIndex: 'openId',
      align: 'center',
      ellipsis: true,
      render: (_, row) => {
        return row?.wechatMiniappUser?.openId || "-"
      }
    },
    {
      title: '小说名称',
      dataIndex: 'bookName',
      key: 'bookName',
      align: 'center',
      ellipsis: true,
      render: (a, b) => {
        return b?.bookInfo?.bookName || "-"
      },
    },
    {
      title: '应用名称',
      dataIndex: 'appName',
      key: 'appName',
      align: 'center',
      ellipsis: true,
      render: (a, b) => {
        return b?.appInfo?.appName;
      },
    },
    {
      title: '分销商名称',
      dataIndex: 'companyName',
      key: 'companyName',
      align: 'center',
      ellipsis: true,
      render: (a, b) => {
        return b?.distributorInfo?.companyName;
      },
    },
    {
      title: '订单号',
      dataIndex: 'orderNo',
      align: 'center',
      ellipsis: true,
    },
    {
      title: '商户订单号',
      dataIndex: 'merchantOrderId',
      align: 'center',
      ellipsis: true,
    },
    {
      title: '订单类型',
      dataIndex: 'orderType',
      align: 'center',
      ellipsis: true,
      valueEnum: getEnum("ORDER_TYPE", "map")
    },
    {
      title: '充值金额',
      dataIndex: 'amount',
      align: 'center',
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '实际支付金额',
      dataIndex: 'payAmount',
      align: 'center',
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '支付渠道',
      dataIndex: 'payChannel',
      align: 'center',
      ellipsis: true,
      hideInSearch: true,
      valueEnum: getEnum("PAY_CHANNEL", "map")
    },
    {
      title: '支付状态',
      dataIndex: 'orderStatus',
      align: 'center',
      ellipsis: true,
      valueEnum: getEnum("ORDER_STATUS", "stateObj", { "2": "success", "1": "processing", "3": "warning", "-2": "error", " -1": "default" })
    },
    {
      title: '支付场景',
      dataIndex: 'orderCondition',
      align: 'center',
      ellipsis: true,
    },
    {
      title: '下单时间',
      dataIndex: 'orderTime',
      align: 'center',
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: '支付时间',
      dataIndex: 'payTime',
      align: 'center',
      ellipsis: true,
      hideInSearch: true,
    },
    {
      title: "充值次数",
      dataIndex: 'chargeNum',
      key: "chargeNum",
      hideInSearch: true,
      align: "center",
      render: (_, row) => {
        return row?.wechatMiniappUser?.chargeNum
      }
    },
    {
      title: "上报金额",
      dataIndex: 'backMoney',
      key: "backMoney",
      hideInSearch: true,
      align: "center",
    },
    {
      title: "上报状态",
      dataIndex: 'backStatus',
      key: "backStatus",
      hideInSearch: true,
      align: "center",
      render: (_, row) => {
        let obj = getEnum("BACK_STATUS", "stateObj", { "0": 'default', "-1": "error", "1": "processing", "2": "success", "3": "warning" })
        let isShowBtn = [1, -1].includes(row?.backStatus)
        return <Space>{obj[row.backStatus]?.text}{isShowBtn}</Space>
      }
    },
    {
      title: '归因渠道',
      dataIndex: 'userChannel',
      align: 'center',
      ellipsis: true,
      valueType: 'select',
      valueEnum: getEnum("USER_CHANNEL", "map"),
      render: (_, row) => {
        let str = getEnum("USER_CHANNEL", "map").get(row?.wechatMiniappUser?.userChannel)
        return str
      }
    },
    {
      title: '渠道名称',
      dataIndex: 'userSource',
      align: 'center',
      ellipsis: true,
      render: (_, row) => {
          return row?.wechatMiniappUser?.userSource
      }
  },
  {
      title: "用户注册时间",
      dataIndex: 'createTime',
      key: "createTime",
      hideInSearch: true,
      align: "center",
      render: (_, row) => {
          return row?.wechatMiniappUser?.createTime
      }
  },
    // 搜索
    {
      title: '支付金额',
      dataIndex: 'amount',
      valueType: 'digitRange',
      width: 170,
      hideInTable: true,
    },
    {
      title: '下单时间',
      dataIndex: 'orderTime',
      valueType: 'dateRange',
      hideInTable: true,
      fieldProps: {
        style: { width: 250 },
      },
    },
  ];
};
