import { useAjax } from '@/Hook/useAjax';
import { apiSysConfigParamsList, apiSysConfigParamsUpdate } from '@/services/distribution/system';
import {
  ActionType,
  BetaSchemaForm,
  PageContainer,
  ProFormInstance,
} from '@ant-design/pro-components';
import { message } from 'antd';
import { useRef, useState } from 'react';
import { columns } from './tableConfig';
import MyProTable from '@/components/MyProTable';

type DataItem = {
  name: string;
  state: string;
};
const Page: React.FC = () => {
  const formRef = useRef<ProFormInstance>();
  const actionRef = useRef<ActionType>();
  let [open, setOpen] = useState<any>(null); //新增作者
  let [editValues, setEditValues] = useState<any>({});
  let SysConfigParamsList = useAjax(() => apiSysConfigParamsList(), { type: 'noPage' });
  let SysConfigParamsUpdate = useAjax((params) => apiSysConfigParamsUpdate(params));

  // 编辑
  const edit = (item: any) => {
    setEditValues(item);
    setTimeout(() => {
      formRef?.current?.setFieldsValue({ ...item });
    }, 100);
    setOpen(true);
  };
  // 新增 or 编辑
  const submit = async (values: any) => {
    if (editValues?.id) {
      values.id = editValues?.id;
    }
    SysConfigParamsUpdate.run(values).then((res) => {
      if (res.code === 200) {
        actionRef?.current?.reload();
        message.success('操作成功!');
        closeForm(false);
      }
    });
    console.log(values);
  };
  // 关闭表单弹窗和重置表单内容
  const closeForm = (b: boolean, values?: any) => {
    if (!b) {
      setEditValues({});
      formRef?.current?.resetFields?.();
      setOpen(b);
    } else {
    }
  };
  return (
    <PageContainer>
      <MyProTable<any, any>
        headerTitle={'作者列表'}
        actionRef={actionRef}
        rowKey={(r) => r.id}
        search={false}
        request={async (params) => {
          return await SysConfigParamsList.run(params);
        }}
        columns={columns(edit)}
        // bordered
      />
      <BetaSchemaForm<DataItem>
        title={'编辑'}
        formRef={formRef}
        width={600}
        open={open}
        onOpenChange={(b) => {
          !b && closeForm(b);
        }}
        layoutType={'ModalForm'}
        labelCol={{ span: 6 }}
        wrapperCol={{ span: 14 }}
        layout="horizontal"
        onFinish={submit}
        columns={[
          {
            title: '配置值',
            dataIndex: 'configValue',
            formItemProps: {
              rules: [
                {
                  required: true,
                  message: '此项为必填项',
                },
              ],
            },
          },
          {
            title: '备注',
            dataIndex: 'remark',
            valueType: 'textarea',
          },
        ]}
        loading={SysConfigParamsUpdate?.loading}
      />
    </PageContainer>
  );
};
export default Page;
