/**传入数组枚举数组和key数组 找到在枚举数组中的description值
 * @param {Array} enumArr 枚举数组
 * @param {Array} arr 要查找的数组
 * */
export function getDescriptions(enumArr: any[], arr: any[]) {
  // 创建一个字典来存储 value 和 description 的映射
  const valueToDescription = enumArr.reduce((acc, item) => {
    acc[item.value] = item.description;
    return acc;
  }, {});
  // 使用 arr2 中的 value 查找对应的 description
  // console.log(enumArr,arr)
  return arr.map((value) => valueToDescription[value]);
}
/**传入数组枚举数组和key数组 找到在枚举数组中的description值
 * @param {Array} enumArr 枚举数组
 * @param {Array} customParams 要插入数据的目标可以不传  { 0: { disabled: true } } 第0个数据内插入disabled: true
 * */
export function convertEnumArr(
  enumArr: any,
  customParams: any = {},
  config?: { key: string; value: string },
) {
  let result: { [key: string | number]: { text: string; disabled?: boolean } } = {};
  for (let item of enumArr) {
    let newItem = { text: config ? item[config.value] : item.description };
    if (customParams[item.value]) {
      Object.assign(newItem, customParams[item.value]);
    }
    result[config ? Number(item[config.key]) : Number(item.value)] = newItem;
  }
  return result;
}

export function convertMenu(onlineMenu: any, localMenu: any) {
  // 构建线上菜单路径映射表
  const onlineMenuMap = buildOnlineMenuMap(onlineMenu);

  // 构建本地菜单路径映射表
  const localMenuMap = buildLocalMenuMap(localMenu);

  // 构建线上菜单的路径映射表
  function buildOnlineMenuMap(menu: any, parentPath = '') {
    const map: any = {};
    for (const item of menu) {
      const fullPath = `${parentPath}${item.path}`.replace('//', '/');
      map[fullPath] = item;
      if (item.children) {
        Object.assign(map, buildOnlineMenuMap(item.children, fullPath));
      }
    }
    return map;
  }

  // 构建本地菜单的路径映射表
  function buildLocalMenuMap(menu: any, parentPath = '') {
    const map: any = {};
    for (const item of menu) {
      const fullPath = `${parentPath}${item.path}`.replace('//', '/');
      map[fullPath] = item;
      if (item.routes) {
        Object.assign(map, buildLocalMenuMap(item.routes, fullPath));
      }
    }
    return map;
  }

  // 查找本地菜单中的图标
  function findLocalIcon(path: any) {
    return localMenuMap[path]?.icon || undefined;
  }
  // 转换菜单
  function convert(onlineMenu: any, localMenuMap: any) {
    return onlineMenu
      .map((item: any) => {
        const path = item.path;
        const localIcon = findLocalIcon(path);

        const newItem = {
          path: path,
          name: item.title || item.name,
          component: item.component,
          icon: localIcon || item.icon, // 使用本地图标
          routes: item.children ? convert(item.children, localMenuMap) : undefined,
        };

        // 保留线上菜单中存在的路径
        if (!onlineMenuMap[path] && !newItem.routes) {
          return null;
        }

        return newItem;
      })
      .filter((item: any) => item !== null); // 过滤掉不存在的路径
  }

  return convert(onlineMenu, localMenuMap);
}
/** base64转File */
export const dataURLtoFile = (dataurl: any, filename: any) => {
  let arr = dataurl.split(','),
      mime = arr[0].match(/:(.*?);/)[1],
      bstr = atob(arr[1]),
      n = bstr.length,
      u8arr = new Uint8Array(n);
  while (n--) {
      u8arr[n] = bstr.charCodeAt(n);
  }
  return new File([u8arr], filename, { type: mime });
};